@@ -5,7 +5,7 @@ use warnings;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '0.106';
+$VERSION = '0.107';
 
 use DateTime 0.08;
 @ISA = 'DateTime';
@@ -44,27 +44,44 @@ sub _ymd2rd {	## no critic (ProhibitUnusedPrivateSubroutines)
     return $rd;
 }
 
-sub _rd2ymd {	## no critic (ProhibitUnusedPrivateSubroutines)
-    my ($self, $rd, $extra) = @_;
+{
+    my @QuarterStart = my @LeapYearQuarterStart = ( 0, 90, 181, 273 );
+    $LeapYearQuarterStart[$_] += 1 for 1 .. 3;
 
-    my $z = $rd + 308;
-    my $y = _floor(($z*100-25)/36525);
-    my $c = $z - _floor(365.25*$y);
-    my $m = int((5*$c + 456)/153);
-    my $d = $c - $start_of_month[$m-3];
-    if ($m > 12) {
-        $m -= 12;
-        $y++;
-    }
+    sub _rd2ymd {	## no critic (ProhibitUnusedPrivateSubroutines)
+	my ($class, $rd, $extra) = @_;
 
-    if ($extra) {
-        # day_of_week, day_of_year
-        my $doy = ($c + 31 + 28 - 1)%365 + 1 +
-                      ($self->_is_leap_year($y) && $m > 2);
-        my $dow = (($rd + 6)%7) + 1;
-        return $y, $m, $d, $dow, $doy;
+	my $z = $rd + 308;
+	my $y = _floor(($z*100-25)/36525);
+	my $c = $z - _floor(365.25*$y);
+	my $m = int((5*$c + 456)/153);
+	my $d = $c - $start_of_month[$m-3];
+	if ($m > 12) {
+	    $m -= 12;
+	    $y++;
+	}
+
+	if ($extra) {
+	    # day_of_week, day_of_year
+	    my $doy = ($c + 31 + 28 - 1)%365 + 1 +
+			  ($class->_is_leap_year($y) && $m > 2);
+	    my $dow = (($rd + 6)%7) + 1;
+
+	    # quarter -- see DateTime::PP->rd2ymd()
+	    my $quarter = int( ( 1 / 3.1 ) * $m ) + 1;
+
+	    my $doq = $doy - ( $class->_is_leap_year( $y ) ?
+		$LeapYearQuarterStart[ $quarter - 1 ] :
+		$QuarterStart[ $quarter - 1 ] );
+
+	    return $y, $m, $d, $dow, $doy, $quarter, $doq;
+	}
+	return $y, $m, $d;
     }
-    return $y, $m, $d;
+}
+
+sub calendar_name {
+    return 'Julian';
 }
 
 sub epoch {
@@ -139,6 +156,10 @@ DateTime, and changes the output of one other method.
 
 =over 4
 
+=item * calendar_name
+
+Returns C<'Julian'>.
+
 =item * gregorian_deviation
 
 Returns the difference in days between the Gregorian and the Julian
@@ -165,6 +186,9 @@ installed.
 
 =back
 
+B<Note> that as of version C<0.106_01>, methods related to quarters
+should work.
+
 =head1 BACKGROUND
 
 The Julian calendar was introduced by Julius Caesar in 46BC.  It
@@ -206,7 +230,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.
 
-Copyright (C) 2018-2021 Thomas R. Wyant, III
+Copyright (C) 2018-2022 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
